/************************************************************************
 *   IRC - Internet Relay Chat, doc/example_module.c
 *   Copyright (C) 2001 Hybrid Development Team
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   $Id: m_newrehash.c,v 1.1.1.1 2002/11/06 13:00:17 ircd Exp $
 */

/* List of ircd includes from ../include/ */
#include "stdinc.h"
#include "handlers.h"
#include "client.h"
#include "common.h"     /* FALSE bleah */
#include "ircd.h"
#include "irc_string.h"
#include "numeric.h"
#include "fdlist.h"
#include "s_bsd.h"
#include "s_conf.h"
#include "s_log.h"
#include "s_serv.h"
#include "send.h"
#include "msg.h"
#include "parse.h"
#include "modules.h"


static void ms_newrehash(struct Client *client_p, struct Client *source_p,
                    int parc, char *parv[]);
static void mo_newrehash(struct Client *client_p, struct Client *source_p,
                    int parc, char *parv[]);

struct Message newrehash_msgtab = {
  "NEWREHASH", 0, 0, 0, 0, MFLG_SLOW, 0,
  {m_unregistered, m_not_oper, ms_newrehash, mo_newrehash}
};

#ifndef STATIC_MODULES
void
_modinit(void)
{
  mod_add_cmd(&newrehash_msgtab);
}

void
_moddeinit(void)
{
  mod_del_cmd(&newrehash_msgtab);
}

const char *_version = "$Revision: 1.1.1.1 $";
#endif

/*
 * ms_newrehash
 *      parv[0] = sender prefix
 *      parv[1] = parameter
 */
static void ms_newrehash(struct Client *client_p, struct Client *source_p,
                   int parc, char *parv[])
{
  if(parc == 1)
  {
    if(IsServer(source_p))
      sendto_one(source_p, ":%s NOTICE %s :You are a server, and sent no parameters",
                 me.name, source_p->name);
    else
      sendto_one(source_p, ":%s NOTICE %s :You are a remote client, and sent no parameters",
      		 me.name, source_p->name);
  }
  else
  {
    if(IsServer(source_p))
      sendto_one(source_p, ":%s NOTICE %s :You are a server, and sent parameters: %s",
		 me.name, source_p->name, parv[1]);
    else
      sendto_one(source_p, ":%s NOTICE %s :You are a remote client, and sent parameters: %s",
		 me.name, source_p->name, parv[1]);
  }
}    
	  
/*
 * mo_newrehash
 *      parv[0] = sender prefix
 *      parv[1] = option
 *	parv[2] = ON
 *	parv[3] = destination server
 */
static void mo_newrehash(struct Client *client_p, struct Client *source_p,
                   int parc, char *parv[])
{		 
  int found = NO;

  if (!IsOperRehash(source_p)) 
  {
    sendto_one(source_p, ":%s NOTICE %s :You need rehash = yes;", me.name, source_p->name);
    return;
  }

  if (parc > 1)
  {
    if (irccmp(parv[1], "ON") == 0)
    {
      if (parv[2] == NULL)
      {
        sendto_one(source_p, form_str(ERR_NEEDMOREPARAMS), me.name, source_p->name, "NEWREHASH");
        return;
      }
      if (hunt_server(client_p, source_p, ":%s REHASH :%s",2,parc,parv)!=HUNTED_ISME)
        return;
    }
  }
}

/* END OF EXAMPLE MODULE */
